@@ -555,26 +555,31 @@ class Epidata:
   # Fetch Delphi's COVID-19 Surveillance Streams
   @staticmethod
   def covidcast(
-          data_source, signal, time_type, geo_type,
-          time_values, geo_value, as_of=None, issues=None, lag=None):
+          data_source, signals, time_type, geo_type,
+          time_values, geo_value, as_of=None, issues=None, lag=None, **kwargs):
     """Fetch Delphi's COVID-19 Surveillance Streams"""
+    # also support old parameter name
+    if signals is None and 'signal' in kwargs:
+      signals=kwargs['signal']
     # Check parameters
-    if data_source is None or signal is None or time_type is None or geo_type is None or time_values is None or geo_value is None:
-      raise Exception('`data_source`, `signal`, `time_type`, `geo_type`, `time_values`, and `geo_value` are all required')
+    if data_source is None or signals is None or time_type is None or geo_type is None or time_values is None or geo_value is None:
+      raise Exception('`data_source`, `signals`, `time_type`, `geo_type`, `time_values`, and `geo_value` are all required')
     if issues is not None and lag is not None:
       raise Exception('`issues` and `lag` are mutually exclusive')
-
     # Set up request
     params = {
       'source': 'covidcast',
       'data_source': data_source,
-      'signal': signal,
+      'signals': Epidata._list(signals),
       'time_type': time_type,
       'geo_type': geo_type,
-      'time_values': Epidata._list(time_values),
-      'geo_value': geo_value,
+      'time_values': Epidata._list(time_values)
     }
 
+    if isinstance(geo_value, (list, tuple)):
+      params['geo_values'] = ','.join(geo_value)
+    else:
+      params['geo_value'] = geo_value
     if as_of is not None:
       params['as_of'] = as_of
     if issues is not None:
@@ -582,6 +587,9 @@ class Epidata:
     if lag is not None:
       params['lag'] = lag
 
+    if 'format' in kwargs:
+      params['format'] = kwargs['format']
+
     # Make the API call
     return Epidata._request(params)
 
@@ -590,3 +598,21 @@ class Epidata:
   def covidcast_meta():
     """Fetch Delphi's COVID-19 Surveillance Streams metadata"""
     return Epidata._request({'source': 'covidcast_meta'})
+
+  # Fetch COVID hospitalization data
+  @staticmethod
+  def covid_hosp(states, dates, issues=None):
+    """Fetch COVID hospitalization data."""
+    # Check parameters
+    if states is None or dates is None:
+      raise Exception('`states` and `dates` are both required')
+    # Set up request
+    params = {
+      'source': 'covid_hosp',
+      'states': Epidata._list(states),
+      'dates': Epidata._list(dates),
+    }
+    if issues is not None:
+      params['issues'] = Epidata._list(issues)
+    # Make the API call
+    return Epidata._request(params)
